==> coil-0.9.4-javadoc.jar: coil-gif/alltypes/index.md <==


### All Types

| Name | Summary |
|---|---|
|

##### [coil.decode.GifDecoder](../coil.decode/-gif-decoder/index.md)

A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [Movie](https://developer.android.com/reference/android/graphics/Movie.html) to decode GIFs.


|

##### [coil.decode.ImageDecoderDecoder](../coil.decode/-image-decoder-decoder/index.md)

A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [ImageDecoder](https://developer.android.com/reference/android/graphics/ImageDecoder.html) to decode GIFs and animated WebPs on Android P and above.


|

##### [coil.drawable.MovieDrawable](../coil.drawable/-movie-drawable/index.md)

A [Drawable](https://developer.android.com/reference/android/graphics/drawable/Drawable.html) that supports rendering [Movie](https://developer.android.com/reference/android/graphics/Movie.html)s (i.e. GIFs).


| (extensions in package coil.extension)

##### [coil.request.Parameters](../coil.extension/coil.request.-parameters/index.md)


| (extensions in package coil.extension)

##### [coil.request.RequestBuilder](../coil.extension/coil.request.-request-builder/index.md)


|

##### [coil.drawable.ScaleDrawable](../coil.drawable/-scale-drawable/index.md)

A [Drawable](https://developer.android.com/reference/android/graphics/drawable/Drawable.html) that centers and scales its [child](file:/Users/Colin/coil/docs/api/coil-base/coil.drawable/-scale-drawable/child.md) to fill its bounds.

==> coil-0.11.0-javadoc.jar: coil-gif/alltypes/index.md <==


### All Types

| Name | Summary |
|---|---|
|

##### [coil.decode.GifDecoder](../coil.decode/-gif-decoder/index.md)

A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [Movie](https://developer.android.com/reference/android/graphics/Movie.html) to decode GIFs.


|

##### [coil.decode.ImageDecoderDecoder](../coil.decode/-image-decoder-decoder/index.md)

A [Decoder](file:/Users/Colin/coil/docs/api/coil-base/coil.decode/-decoder/index.md) that uses [ImageDecoder](https://developer.android.com/reference/android/graphics/ImageDecoder.html) to decode GIFs, animated WebPs, and animated HEIFs.


|

##### [coil.drawable.MovieDrawable](../coil.drawable/-movie-drawable/index.md)

A [Drawable](https://developer.android.com/reference/android/graphics/drawable/Drawable.html) that supports rendering [Movie](https://developer.android.com/reference/android/graphics/Movie.html)s (i.e. GIFs).


| (extensions in package coil.extension)

##### [coil.request.Parameters](../coil.extension/coil.request.-parameters/index.md)


| (extensions in package coil.extension)

##### [coil.request.RequestBuilder](../coil.extension/coil.request.-request-builder/index.md)


|

##### [coil.drawable.ScaleDrawable](../coil.drawable/-scale-drawable/index.md)

A [Drawable](https://developer.android.com/reference/android/graphics/drawable/Drawable.html) that centers and scales its [child](file:/Users/Colin/coil/docs/api/coil-base/coil.drawable/-scale-drawable/child.md) to fill its bounds.
